@@ -1,7 +1,7 @@
 package usw;
 use 5.012005;
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 
 use Encode qw(is_utf8 encode_utf8 decode_utf8);
 use utf8();
@@ -14,11 +14,9 @@ sub import {
     strict->import;
     warnings->import( 'all', FATAL => 'recursion' );
 
-    my $out = first { $_ =~ /^cp\d+$/ } @_;
-    $out ||= 'UTF-8';
-    binmode \*STDIN,  ":encoding($out)";
-    binmode \*STDOUT, ":encoding($out)";
-    binmode \*STDERR, ":encoding($out)";
+    binmode \*STDIN,  ":encoding(UTF-8)";
+    binmode \*STDOUT, ":encoding(UTF-8)";
+    binmode \*STDERR, ":encoding(UTF-8)";
     return unless @_;
 
     $SIG{__WARN__} = \&_redecode if first { $_ eq 'warn' } @_;
@@ -52,9 +50,10 @@ usw - use utf8; use strict; use warnings; in one line.
  use utf8;
  use strict;
  use warnings;
- binmode \*STDOUT, ':encoding(UTF-8)';
- binmode \*STDERR, ':encoding(UTF-8)';
-  
+ binmode STDIN,  ':encoding(UTF-8)';
+ binmode STDOUT, ':encoding(UTF-8)';
+ binmode STDERR, ':encoding(UTF-8)';
+
 =head1 DESCRIPTION
 
 usw is a shortcut pragma mostly for one-liners.
@@ -63,7 +62,7 @@ May be useful for those who write the above code every single time
 
 =head2 HOW TO USE
 
-  use usw;
+ use usw;
 
 It seems a kind of pragmas but doesn't spent
 L<%^H|https://metacpan.org/pod/perlpragma#Key-naming>
@@ -97,14 +96,23 @@ of encoding only the file path like that:
 
 This import is B<only> if written.
 
-Since version 0.04, you can write like this:
+The feature added on version 0.04 has been removed in 0.05.
 
- use usw qw(cp932);
+use L<usww> instead of it running this on Windows.
 
-This option changes at once C<STDIN>,C<STDOUT>,C<STDERR> to C<cp\d+>
+=head1 SEE ALSO
 
-defaults to C<UTF-8> and should B<NOT> be set except on Windows.
+=over
 
+=item L<usww> - another implement for Windows
+
+=item L<Encode>
+
+=item L<binmode|https://perldoc.perl.org/functions/binmode>
+
+=item L<%SIG|https://perldoc.perl.org/variables/%25SIG>
+
+=back
 
 =head1 LICENSE
 
